<template>
  <div class="authorityManagement_box">
    <My-bread :list="['数据管理', '版本管理']"></My-bread>
    <el-divider />
    <div class="searchComp">
      <el-form ref="ruleForm" :model="ruleForm" :inline="true">
        <el-form-item label="关键字" prop="name">
          <el-input v-model="ruleForm.name" placeholder="请输入" />
        </el-form-item>
        <el-form-item>
          <el-button
            @click="submitForm('ruleForm')"
            icon="el-icon-search"
            type="primary"
            size="small"
            >查询</el-button
          >
          <!-- <el-button
            @click="resetForm('ruleForm')"
            icon="el-icon-refresh"
            type="info"
            size="small"
            >重置</el-button
          >
          <span style="display:none">{{ pathId }}</span> -->
        </el-form-item>
      </el-form>
    </div>
    <div class="bottom">
      <div class="leftTree">
        <catalogueTree></catalogueTree>
      </div>
      <div class="rightTable">
        <div class="table_box">
          <el-table
            :data="tableData"
            border
            style="width: 100%"
            fit
            height="99%"
          >
            <!-- <el-table-column type="selection" width="40" /> -->
            <el-table-column width="50" type="index" label="序号" />
            <el-table-column min-width="130" prop="name" label="数据名称" />
            <el-table-column min-width="160" prop="path" label="所属目录" />
            <el-table-column
              min-width="100"
              prop="create_time"
              label="创建时间"
            />
            <el-table-column
              min-width="50"
              prop="create_user"
              label="创建人员"
            />
            <el-table-column min-width="80" prop="up_unit" label="上传单位" />
            <el-table-column min-width="50" prop="status" label="数据状态" />
            <el-table-column min-width="50" prop="version" label="数据版本" />
            <el-table-column min-width="50" label="操作">
              <template slot-scope="scope">
                <!-- <el-link @click="showDetail(scope.$index, scope.row)"
                  >查看</el-link
                > -->
                <el-link
                  @click="handleEdit(scope.$index, scope.row)"
                  style="margin-left: 10px"
                  >修改</el-link
                >
                <!-- <el-link
                  @click="handleDelete(scope.$index, scope.row)"
                  style="margin-left: 10px"
                  >删除</el-link
                > -->
              </template>
            </el-table-column>
          </el-table>
        </div>
        <div
          style="margin-top: 20px; margin-left: 200px"
          class="pagination_box"
        >
          <el-pagination
            @size-change="handleSizeChange"
            @current-change="handleCurrentChange"
            :current-page="currentPage"
            :page-sizes="[10, 20, 50, 100]"
            :page-size="10"
            layout="total, sizes, prev, pager, next, jumper"
            :total="count"
          >
          </el-pagination>
        </div>
      </div>
    </div>
    <div class="infoBox" v-show="showinfoBox">
      <el-card class="box-card">
        <div slot="header" class="clearfix">
          <span>详细信息</span>
          <div style="float: right; cursor: pointer" @click="closeDetial">
            <i class="el-icon-close"></i>
          </div>
        </div>
        <div class="contentBox">
          <p>数据名称：{{ itemdetail.name }}</p>
          <el-divider></el-divider>
          <p>所属目录：{{ itemdetail.path }}</p>
          <el-divider></el-divider>
          <p>创建时间：{{ itemdetail.create_time }}</p>
          <el-divider></el-divider>
          <p>创建人员：{{ itemdetail.create_user }}</p>
          <el-divider></el-divider>
          <p>上传单位：{{ itemdetail.up_unit }}</p>
          <el-divider></el-divider>
          <p>数据状态：{{ itemdetail.status }}</p>
          <el-divider></el-divider>
          <p>数据版本：{{ itemdetail.version }}</p>
        </div>
      </el-card>
    </div>
    <el-dialog title="修改详情" :visible.sync="dialogFormVisible">
      <el-form :model="upform">
        <el-form-item label="数据名称" :label-width="formLabelWidth">
          <el-input
            v-model="upform.name"
            autocomplete="off"
            disabled
          ></el-input>
        </el-form-item>
        <el-form-item label="所属目录" :label-width="formLabelWidth">
          <el-input
            v-model="upform.path"
            autocomplete="off"
            disabled
          ></el-input>
        </el-form-item>
        <el-form-item label="创建时间" :label-width="formLabelWidth">
          <el-date-picker
            v-model="upform.create_time"
            value-format="yyyy-MM-dd"
            type="date"
            placeholder="选择日期"
            style="width: 100%"
            disabled
          >
          </el-date-picker>
        </el-form-item>
        <el-form-item label="创建人员" :label-width="formLabelWidth">
          <el-input
            v-model="upform.create_user"
            autocomplete="off"
            disabled
          ></el-input>
        </el-form-item>
        <el-form-item label="上传单位" :label-width="formLabelWidth">
          <el-input
            v-model="upform.up_unit"
            autocomplete="off"
            disabled
          ></el-input>
        </el-form-item>
        <el-form-item label="数据状态" :label-width="formLabelWidth">
          <el-input
            v-model="upform.status"
            autocomplete="off"
            disabled
          ></el-input>
        </el-form-item>
        <el-form-item label="数据版本" :label-width="formLabelWidth">
          <el-input v-model="upform.version" autocomplete="off"></el-input>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="updateForm">确 定</el-button>
        <el-button @click="dialogFormVisible = false">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import {
  queryMetaData,
  queryDataCount,
  updateMetaData,
  dltMetaDatas,
} from "../../api/api";
import catalogueTree from "../../components/catalogueTree.vue";
import MyBread from "../../components/MyBread.vue";
export default {
  name: "versionManage",
  components: { MyBread, catalogueTree },
  data() {
    return {
      multipleSelection: [],
      formLabelWidth: "120px",
      dialogFormVisible: false,
      upform: {},
      showinfoBox: false,
      itemdetail: {},
      ruleForm: {
        name: "",
      },
      count: 0,
      pageSize: 10,
      pageNum: 1,
      nowPid: -1,
      tableData: [],
      currentPage: 1,
      searchName: "",
    };
  },
  created() {
    this.getMetaData(10, 1, "", -1);
    this.getMetaCount("", -1);
  },
  computed: {
    pathId() {
      return this.$store.state.cataNode.id;
    },
  },
  methods: {
    // 请求数据内容
    getMetaData(size, num, name, pid) {
      queryMetaData(size, num, name, pid).then((res) => {
        this.tableData = res.data;
      });
    },
    // 请求数据数量
    getMetaCount(name, pid) {
      queryDataCount(name, pid).then((res) => {
        this.count = res.data;
      });
    },
    // 关键字查询
    submitForm(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          this.searchName = this.ruleForm.name.trim();
          this.getMetaData(10, 1, this.searchName);
          this.getMetaCount(this.searchName);
        } else {
          console.log("error submit!!");
          return false;
        }
      });
    },
    // 重置查询
    resetForm(formName) {
      this.getMetaData(10, 1, "", -1);
      this.getMetaCount("");
      this.searchName = "";
      this.$refs[formName].resetFields();
    },
    // 获取多选选中的对象
    handleSelectionChange(val) {
      this.multipleSelection = val;
      console.log(val);
    },
    // 查看界面
    showDetail(index, row) {
      // console.log(index, row);
      this.showinfoBox = true;
      this.itemdetail = row;
    },
    // 关闭查看
    closeDetial() {
      this.showinfoBox = false;
      this.itemdetail = {};
    },
    // 修改界面
    handleEdit(index, row) {
      this.dialogFormVisible = true;
      this.upform = JSON.parse(JSON.stringify(row));
    },
    // 提交修改
    updateForm() {
      this.$confirm("是否确定编辑?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          this.dialogFormVisible = false;
          updateMetaData(this.upform).then((res) => {
            if (res.data == 1) {
              this.$message({
                message: "修改成功",
                type: "success",
              });
            }
            this.getMetaData(10, 1);
          });
        })
        .catch(() => {});
    },
    // 删除
    handleDelete(index, row) {
      // console.log(index, row);
      this.$confirm("确定是否删除?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          dltMetaDatas({ id: row.id }).then((res) => {
            if (res.data == 1) {
              this.$message({
                type: "success",
                message: "删除成功!",
              });
              this.getMetaData(10, 1, "");
              this.getMetaCount("");
            }
          });
          // 多选删除
          // if (this.multipleSelection.length > 1) {
          //   let ids = "";
          //   this.multipleSelection.forEach((e) => {
          //     ids += `id=${e.id}&`;
          //   });
          //   let res = ids.substring(0, ids.length - 1);
          //   dltMetaDatas(res).then((res) => {
          //     console.log(res);
          //   });
          // }
        })
        .catch(() => {});
    },

    // 条数修改
    handleSizeChange(val) {
      this.pageSize = val;
      this.getMetaData(this.pageSize, 1, this.searchName, this.nowPid);
      this.getMetaCount(this.searchName, this.nowPid);
    },
    // 页数修改
    handleCurrentChange(val) {
      this.pageNum = val;
      this.getMetaData(
        this.pageSize,
        this.pageNum,
        this.searchName,
        this.nowPid
      );
      this.getMetaCount(this.searchName, this.nowPid);
    },
  },
  watch: {
    pathId: {
      immediate: true,
      handler(val) {
        if (val) this.nowPid = val;
        this.getMetaData(10, 1, "", this.nowPid);
        this.getMetaCount("", this.nowPid);
      },
    },
  },
};
</script>
<style lang="less" scoped>
//@import url(); 引入公共css类
.authorityManagement_box {
  background: rgb(240, 242, 245);
  border-radius: 10px;
  height: 100%;
  padding: 10px;
  box-sizing: border-box;
  .searchComp {
    margin: 10px auto;
    background: #fff;
    border-radius: 5px;
    border: 1px solid rgb(202, 201, 204);
    .el-form-item {
      margin: 5px;
    }
    .el-input {
      width: 467px;
    }
  }
  .bottom {
    width: 100%;
    height: 85%;
    display: flex;
    .leftTree {
      width: 344px;
      background: #f4f8ff;
      border-radius: 10px;
      overflow: auto;
    }
    .rightTable {
      height: 100%;
      width: 77.8%;
      // background-color: red;
      .table_box {
        width: 100%;
        height: 93%;
        margin: 0 auto;
        overflow: auto;
        background: #fff;
        .el-table {
          height: 100%;
        }
        .el-table /deep/ .el-table__header-wrapper tr th {
          background-color: rgb(255, 255, 255) !important;
          color: rgb(0, 0, 0);
        }
        // 修改每行样式：
        .el-table /deep/ .el-table__row {
          background-color: rgba(255, 255, 255) !important;
          color: rgb(0, 0, 0);
        }
        .el-table /deep/ .el-table__body tr.current-row > td {
          background-color: rgb(211, 211, 211) !important;
        }
        .el-table /deep/ .el-table__body tr:hover > td {
          background-color: rgb(211, 211, 211) !important;
        }
        // 修改表格每行边框的样式：
        .el-table /deep/ td,
        .el-table /deep/ th.is-leaf {
          border-bottom: 1px solid #eee;
          border-right: 1px solid #eee;
        }
        .el-table /deep/ .el-table__cell {
          padding: 0;
        }
        // 设置表格每行的高度：
        .el-table /deep/ .el-table__header tr,
        .el-table /deep/ .el-table__header th {
          height: 40px;
        }
        .el-table__body tr,
        .el-table__body td {
          height: 40px;
          padding: 0;
        }
        // 设置表格边框颜色：

        .el-table--border::after,
        .el-table--group::after {
          width: 0;
        }
        .el-table::before {
          height: 0;
        }
        //   a {
        //     color: #000;
        //   }
      }
    }
  }
  .infoBox {
    width: 500px;
    border: 1px solid #eee;
    position: absolute;
    z-index: 100;
    top: 15%;
    right: 25%;
    background-color: #fff;
    .el-card {
      background-color: transparent;
      span {
        font-size: 16px;
        font-weight: 600;
      }
    }
    .contentBox {
      margin: 0 aotu 10px;
      p {
        // background-color: #bfa;
        // margin-bottom: 10px;
        font-size: 14px;
      }
    }
  }
  /deep/ .el-dialog {
    width: 500px !important;
    margin-top: 10vh !important;
  }

  /deep/.el-dialog .el-input__inner {
    width: 300px;
  }
  /deep/ .el-dialog__body {
    padding: 0px 30px;
  }
  /deep/ .el-dialog__footer {
    padding-top: 0 !important;
    width: 200px;
    display: flex;
    margin: 0 auto;
    justify-content: center;
  }
}
</style>
